@@ -14,7 +14,7 @@
 
 class Synchronous : public TQObject
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   Synchronous(uint timeout = 0); // timeout is ms (0 == no timeout)
