@@ -223,7 +223,7 @@ void GenericConfig::deleteGroup(const TQString &group)
 TQVariant GenericConfig::readVariantEntry(const TQString &key, const TQVariant &defValue) const
 {
   switch (defValue.type()) {
-    case TQVariant::Bool: return TQVariant(readBoolEntry(key, defValue.toBool()), 0);
+    case TQVariant::Bool: return TQVariant(readBoolEntry(key, defValue.toBool()));
     case TQVariant::UInt: return readUIntEntry(key, defValue.toUInt());
     default: break;
   }
