@@ -12,7 +12,7 @@ class Q3Process;
 
 class TDEProcess : public TQObject
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   TDEProcess(TQObject *parent = 0, const char *name = 0);
