@@ -4,8 +4,8 @@
 #undef TDECORE_EXPORT
 #define TDECORE_EXPORT
 
-#undef KDE_DEPRECATED
-#define KDE_DEPRECATED
+#undef TDE_DEPRECATED
+#define TDE_DEPRECATED
 
 #undef I18N_NOOP
 #define I18N_NOOP(x) (x)
