@@ -33,7 +33,7 @@ private:
 //-----------------------------------------------------------------------------
 class HexWordEditor : public Device::HexWordEditor, public MemoryCaster
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   HexWordEditor(Memory &memory, TQWidget *parent)
@@ -49,7 +49,7 @@ private:
 //-----------------------------------------------------------------------------
 class MemoryRangeEditor : public Device::MemoryRangeEditor, public MemoryCaster
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   MemoryRangeEditor(Memory &memory, TQWidget *parent);
@@ -65,7 +65,7 @@ private:
 //-----------------------------------------------------------------------------
 class MemoryTypeEditor : public Device::MemoryTypeEditor, public MemoryCaster
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   MemoryTypeEditor(const HexView *hexview, Memory &memory, TQWidget *parent);
