@@ -20,7 +20,7 @@ namespace Pic
 
 class HexView : public Device::HexView
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   HexView(const HexEditor &editor, TQWidget *parent);
