@@ -41,7 +41,7 @@ private:
 //-----------------------------------------------------------------------------
 class MemoryEditor : public Device::MemoryEditor, public MemoryCaster
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   MemoryEditor(MemoryRangeType type, Memory &memory, TQWidget *parent, const char *name)
@@ -51,7 +51,7 @@ public:
 //-----------------------------------------------------------------------------
 class MemoryEditorLegend : public MemoryEditor
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   MemoryEditorLegend(MemoryRangeType type, Memory &memory, TQWidget *parent);
@@ -92,7 +92,7 @@ private:
 //-----------------------------------------------------------------------------
 class HexWordEditor : public Device::HexWordEditor, public MemoryCaster
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   HexWordEditor(MemoryRangeType type, Memory &memory, TQWidget *parent);
@@ -107,7 +107,7 @@ private:
 //-----------------------------------------------------------------------------
 class MemoryRangeEditor : public Device::MemoryRangeEditor, public MemoryCaster
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   MemoryRangeEditor(MemoryRangeType type, Memory &memory,
@@ -134,7 +134,7 @@ private:
 //-----------------------------------------------------------------------------
 class MemoryTypeEditor : public Device::MemoryTypeEditor, public MemoryCaster
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   MemoryTypeEditor(const HexView *hexview, MemoryRangeType type, Memory &memory, TQWidget *parent, const char *name);
@@ -147,7 +147,7 @@ private:
 //-----------------------------------------------------------------------------
 class MemoryTypeRangeEditor : public MemoryTypeEditor
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   MemoryTypeRangeEditor(const HexView *hexview, MemoryRangeType type, Memory &memory, TQWidget *parent);
@@ -160,7 +160,7 @@ protected:
 //-----------------------------------------------------------------------------
 class MemoryUserIdEditor : public MemoryTypeRangeEditor
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   MemoryUserIdEditor(const HexView *hexview, Memory &memory, TQWidget *parent);
@@ -181,7 +181,7 @@ private:
 //-----------------------------------------------------------------------------
 class MemoryCalibrationEditor : public MemoryTypeEditor
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   MemoryCalibrationEditor(const HexView *hexview, Memory &memory, TQWidget *parent);
