@@ -85,7 +85,7 @@ private:
 //-----------------------------------------------------------------------------
 class Dialog : public ::Dialog
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   Dialog(const TQString &device, Type type, TQWidget *parent);
@@ -118,7 +118,7 @@ private:
 //-----------------------------------------------------------------------------
 class ComboBox : public TQComboBox
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   ComboBox(bool withAuto, TQWidget *parent);
@@ -133,7 +133,7 @@ private:
 //-----------------------------------------------------------------------------
 class Button : public TQWidget
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   Button(bool withAuto, TQWidget *parent);
@@ -153,7 +153,7 @@ private:
 //-----------------------------------------------------------------------------
 class Browser : public KTextBrowser
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   Browser(TQWidget *parent);
@@ -168,7 +168,7 @@ public slots:
 //-----------------------------------------------------------------------------
 class View : public TabWidget
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   View(TQWidget *parent);
@@ -187,7 +187,7 @@ private:
 //-----------------------------------------------------------------------------
 class Editor : public DeviceEditor
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   Editor(const TQString &title, const TQString &tag, TQWidget *parent);
