@@ -22,7 +22,7 @@ class TQEvent;
 //-----------------------------------------------------------------------------
 class SwitchToDialog : public Dialog
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   SwitchToDialog(const TQStringList &names, TQWidget *parent);
@@ -35,7 +35,7 @@ private:
 //-----------------------------------------------------------------------------
 class EditorTabBar : public TabBar
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   EditorTabBar(TQWidget *parent) : TabBar(parent, "editor_tab_bar") {}
@@ -66,7 +66,7 @@ private:
 //-----------------------------------------------------------------------------
 class EditorManager : public TabWidget
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   EditorManager(TQWidget *parent);
