@@ -21,7 +21,7 @@ class HexEditor;
 
 class HexEditorPart : public KParts::ReadWritePart
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   HexEditorPart(HexEditor *editor);
@@ -35,7 +35,7 @@ private:
 //-----------------------------------------------------------------------------
 class HexEditor : public DeviceEditor
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   HexEditor(const TQString &name, TQWidget *parent);
