@@ -29,7 +29,7 @@ namespace DeviceChooser { class Button; }
 
 class ProjectEditor : public Dialog
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   ProjectEditor(Project &project, TQWidget *parent);
