@@ -19,7 +19,7 @@
 //-----------------------------------------------------------------------------
 class PopupMenu : public TDEPopupMenu
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   PopupMenu() : _index(1) {}
