@@ -36,7 +36,7 @@ extern const FillOptions FILL_OPTIONS[];
 //----------------------------------------------------------------------------
 class Main : public MainBase
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   Main();
