@@ -26,7 +26,7 @@ TQ_DECLARE_OPERATORS_FOR_FLAGS(CommandProperties)
 //----------------------------------------------------------------------------
 class Interactive : public TQObject, public Log::Base
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   Interactive(TQObject *parent);
