@@ -12,6 +12,6 @@
 
 TQPixmap Debugger::OptionsConfigWidget::pixmap() const
 {
-  KIconLoader loader;
-  return loader.loadIcon("piklab_config_debugger", KIcon::Toolbar, KIcon::SizeMedium);
+  TDEIconLoader loader;
+  return loader.loadIcon("piklab_config_debugger", TDEIcon::Toolbar, TDEIcon::SizeMedium);
 }
