@@ -26,7 +26,7 @@ namespace Hardware
 //-----------------------------------------------------------------------------
 class HConfigWidget : public TQFrame
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   HConfigWidget(::Programmer::Base &base, TQWidget *parent, bool edit);
@@ -47,7 +47,7 @@ class ConfigWidget;
 
 class EditDialog : public KDialogBase
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   EditDialog(ConfigWidget *parent, const TQString &name, const Port::Description &pd, Data *data);
@@ -68,7 +68,7 @@ private:
 //-----------------------------------------------------------------------------
 class ConfigWidget : public ::Programmer::ConfigWidget
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   ConfigWidget(::Programmer::Base *base, Config *config, TQWidget *parent);
