@@ -20,7 +20,7 @@ namespace Programmer { class Group; }
 
 class PortSelector : public TQFrame
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   PortSelector(TQWidget *parent);
