@@ -28,7 +28,7 @@ END_DECLARE_CONFIG_WIDGET
 //----------------------------------------------------------------------------
 class SelectConfigWidget : public ::ConfigWidget
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   SelectConfigWidget();
