@@ -22,7 +22,7 @@ class HardwareDescription;
 
 class ConfigWidget: public ::ConfigWidget
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   ConfigWidget(const Group &group, TQWidget *parent);
