@@ -21,7 +21,7 @@ class Hardware;
 //-----------------------------------------------------------------------------
 class ProgrammerBase : public Icd::ProgrammerBase
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   ProgrammerBase(const Programmer::Group &group, const Pic::Data *data)
