@@ -18,7 +18,7 @@ namespace Icd
 //----------------------------------------------------------------------------
 class ProgrammerBase : public ::Programmer::PicBase
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   ProgrammerBase(const Programmer::Group &group, const Pic::Data *data, const char *name)
