@@ -24,7 +24,7 @@ class HardwareDescription;
 
 class Manager : public TQObject, public Log::Base
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   Manager(TQObject *parent);
