@@ -18,7 +18,7 @@ namespace PicdemBootloader
 //-----------------------------------------------------------------------------
 class ProgrammerBase : public Bootloader::ProgrammerBase
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   ProgrammerBase(const Programmer::Group &group, const Pic::Data *data);
