@@ -16,7 +16,7 @@ namespace Pickit1
 //----------------------------------------------------------------------------
 class Base : public Pickit::Base
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   Base(const Programmer::Group &group, const Pic::Data *data) : Pickit::Base(group, data) {}
