@@ -17,7 +17,7 @@ namespace Pickit
 {
 class AdvancedDialog : public ::Programmer::PicAdvancedDialog
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   AdvancedDialog(Base &base, TQWidget *parent, const char *name);
