@@ -19,7 +19,7 @@ namespace TinyBootloader
 class XmlToData : public Programmer::XmlToData<Data>
 {
 public:
-  XmlToData() : Programmer::XmlToData<Data>("tbl_bootloader", "TinyBootloader") {}
+  XmlToData(const TQString &folder) : Programmer::XmlToData<Data>(folder, "tbl_bootloader", "TinyBootloader") {}
 
 private:
   virtual void parseData(TQDomElement element, Data &data);
