@@ -17,7 +17,7 @@ namespace CCSC
 //----------------------------------------------------------------------------
 class ConfigWidget : public ToolConfigWidget
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   ConfigWidget(Project *project);
