@@ -16,7 +16,7 @@ namespace GPUtils
 //-----------------------------------------------------------------------------
 class Process : public Compile::Process
 {
-Q_OBJECT
+TQ_OBJECT
   
 private:
   virtual TQString deviceName() const;
@@ -26,7 +26,7 @@ private:
 //-----------------------------------------------------------------------------
 class AssembleFile : public Process
 {
-Q_OBJECT
+TQ_OBJECT
   
 private:
   virtual void logStderrLine(const TQString &line);
@@ -35,7 +35,7 @@ private:
 //-----------------------------------------------------------------------------
 class AssembleStandaloneFile : public AssembleFile
 {
-Q_OBJECT
+TQ_OBJECT
   
 private:
   virtual TQString outputFiles() const;
@@ -45,7 +45,7 @@ private:
 //-----------------------------------------------------------------------------
 class AssembleProjectFile : public AssembleFile
 {
-Q_OBJECT
+TQ_OBJECT
   
 private:
   virtual TQString outputFiles() const;
@@ -55,7 +55,7 @@ private:
 //-----------------------------------------------------------------------------
 class LinkProject : public Process
 {
-Q_OBJECT
+TQ_OBJECT
   
 private:
   virtual TQString outputFiles() const;
@@ -66,7 +66,7 @@ private:
 //-----------------------------------------------------------------------------
 class LibraryProject : public Process
 {
-Q_OBJECT
+TQ_OBJECT
   
 private:
   virtual TQString outputFiles() const;
