@@ -25,7 +25,7 @@ namespace Tool { class Group; }
 //----------------------------------------------------------------------------
 class ToolchainConfigWidget : public ::ConfigWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   ToolchainConfigWidget(const Tool::Group &group, TQWidget *parent);
