@@ -15,7 +15,7 @@ namespace JALV2
 {
 class CompileFile : public Compile::Process
 {
-Q_OBJECT
+TQ_OBJECT
   
 protected:
   virtual TQString deviceName() const { return _data.device; }
