@@ -25,7 +25,7 @@ class ToolConfigWidget;
 //----------------------------------------------------------------------------
 class HelpDialog : public Dialog
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   HelpDialog(TQWidget *parent);
@@ -34,7 +34,7 @@ public:
 //----------------------------------------------------------------------------
 class ToolsConfigWidget : public ConfigWidget
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   ToolsConfigWidget(Project *project, TQWidget *parent);
