@@ -16,7 +16,7 @@ namespace PIC30
 //-----------------------------------------------------------------------------
 class Process : public Compile::Process
 {
-Q_OBJECT
+TQ_OBJECT
   
 protected:
   virtual TQString deviceName() const { return _data.device; }
@@ -25,7 +25,7 @@ protected:
 //-----------------------------------------------------------------------------
 class CompileFile : public Process
 {
-Q_OBJECT
+TQ_OBJECT
   
 protected:
   virtual TQStringList genericArguments(const Compile::Config &config) const;
@@ -36,7 +36,7 @@ protected:
 //-----------------------------------------------------------------------------
 class CompileStandaloneFile : public CompileFile
 {
-Q_OBJECT
+TQ_OBJECT
   
 protected:
   virtual TQStringList genericArguments(const Compile::Config &config) const;
@@ -46,7 +46,7 @@ protected:
 //-----------------------------------------------------------------------------
 class CompileProjectFile : public CompileFile
 {
-Q_OBJECT
+TQ_OBJECT
   
 protected:
   virtual TQStringList genericArguments(const Compile::Config &config) const;
@@ -55,7 +55,7 @@ protected:
 //-----------------------------------------------------------------------------
 class AssembleFile : public Process
 {
-Q_OBJECT
+TQ_OBJECT
   
 protected:
   virtual TQString outputFilepath() const { return filepath(PURL::Object); }
@@ -67,7 +67,7 @@ protected:
 //-----------------------------------------------------------------------------
 class AssembleStandaloneFile : public AssembleFile
 {
-Q_OBJECT
+TQ_OBJECT
   
 protected:
   virtual TQStringList genericArguments(const Compile::Config &config) const;
@@ -76,7 +76,7 @@ protected:
 //-----------------------------------------------------------------------------
 class AssembleProjectFile : public AssembleFile
 {
-Q_OBJECT
+TQ_OBJECT
   
 protected:
   virtual TQStringList genericArguments(const Compile::Config &config) const;
@@ -85,7 +85,7 @@ protected:
 //-----------------------------------------------------------------------------
 class Link : public Process
 {
-Q_OBJECT
+TQ_OBJECT
   
 protected:
   virtual TQString outputFilepath() const;
@@ -97,7 +97,7 @@ protected:
 //-----------------------------------------------------------------------------
 class LinkStandalone : public Link
 {
-Q_OBJECT
+TQ_OBJECT
   
 protected:
   virtual TQStringList genericArguments(const Compile::Config &config) const;
@@ -106,7 +106,7 @@ protected:
 //-----------------------------------------------------------------------------
 class LinkProject : public Link
 {
-Q_OBJECT
+TQ_OBJECT
   
 protected:
   virtual TQStringList genericArguments(const Compile::Config &config) const;
@@ -115,7 +115,7 @@ protected:
 //-----------------------------------------------------------------------------
 class LibraryProject : public Process
 {
-Q_OBJECT
+TQ_OBJECT
   
 protected:
   virtual TQStringList genericArguments(const Compile::Config &config) const;
@@ -126,7 +126,7 @@ protected:
 //-----------------------------------------------------------------------------
 class BinToHex : public Process
 {
-Q_OBJECT
+TQ_OBJECT
   
 protected:
   virtual TQString inputFilepath(uint i) const;
